==> kleandisk-2.0beta2.tar.gz: kleandisk-2.0beta2/kleandisk/abprocess.h <==
/***************************************************************************
                          abprocess.h  -  description
                             -------------------
    begin                : Sat Sep 4 1999
    copyright            : (C) 1999 by Arjan Buursink
    email                : buursink@casema.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef ABPROCESS_H
#define ABPROCESS_H

#include <qstrlist.h>
#include <qstring.h>

#include <kprocess.h>

/**
  *@author Arjan Buursink
  */

class ABProcess : public KProcess  {
	Q_OBJECT
public:
	ABProcess(QString);
	~ABProcess();
	QStrList *output;
	void init();
	QString std_err;
	QString name(){return nm;};
	QString error();
public slots:
	void slotReceivedStdout(KProcess *,char * b, int l);
	void slotReceivedStderr(KProcess *,char *, int);
private:
	QString std_out;
	QString nm;
signals:
	void receivedOutput(int,QString);
};

#endif

==> kleandisk-2.1beta2.tar.gz: kleandisk-2.1beta2/kleandisk/abprocess.h <==
/***************************************************************************
                          abprocess.h  -  description
                             -------------------
    begin                : Sat Sep 4 1999
    copyright            : (C) 1999 by Arjan Buursink
    email                : buursink@casema.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef ABPROCESS_H
#define ABPROCESS_H

#include <qstrlist.h>
#include <qstring.h>
#include <qtextstream.h>
#include <qfile.h>

#include <kprocess.h>

/**
  *@author Arjan Buursink
  */

class ABProcess : public KShellProcess  {
	Q_OBJECT
public:
	ABProcess(bool se = true);
	~ABProcess();
	QStrList *output;
	void init();
	QString std_err;
	bool error();
	QString errorText();
	void exec(bool block = false);
public slots:
	void slotReceivedStdout(KProcess *,char *, int l);
	void slotReceivedStderr(KProcess *,char *, int);
	void slotProcessExited();	
private:
	QFile file;
	QTextStream log;
	QString std_out;
	bool showerror;
signals:
	void receivedOutput(int,QString);
};

#endif
